import React, {PropTypes} from 'react';
import $ from 'jquery';
import _ from 'underscore';

// wrap the jQuery plugin in a react component
// there are React dotdotdot plugins, but using the jQuery one to preserve truncation appearance
export class DotDotDot extends React.Component {
    componentDidMount() {
        this._element && $(this._element).dotdotdot();
    }

    render() {
        return (
            <div>
                {React.cloneElement(this.props.children, { ref: (e) => this._element = e })}
            </div>
        );
    }
}

DotDotDot.propTypes = {
    children: PropTypes.element
};

// For inserting dynamic styles
// Appends the children of the component (which must be a string of CSS) to the head element
// Use es6 multi-line strings (``) to maintain your sanity
export class Style extends React.Component {
    constructor() {
        super();
        const styleNode = document.createElement('style');
        styleNode.type = 'text/css';
        this._styleNode = styleNode;
    }

    componentDidMount() {
        const head = document.getElementsByTagName('head')[0];
        head.appendChild(this._styleNode);
    }

    render() {
        this._styleNode.innerHTML = this.props.children;
        return null;
    }
}

Style.propTypes = {
    children: PropTypes.string.isRequired
};

// there are lots of checks for arr[0] === "true" due to select box inputs
// storing the data as a string array
export const selectBoxIsTrue = (value) => value && value[0] === "true";

// tag that removes indentation and newlines from template strings
export const dedent = (strs, ...args) => {
    return _.flatten(_.zip(strs.map(s => s.replace(/\s\s+/g, ' ')), args)).join('');
};
